@@ -8,36 +8,43 @@ import datetime
 import logging
 from typing import List, Optional
 
-from pydantic import BaseModel, Field
+from pydantic import Field
 
 from lunchable._config import APIConfig
+from lunchable.models._base import LunchableModel
 from lunchable.models._core import LunchMoneyAPIClient
 
 logger = logging.getLogger(__name__)
 
 
-class CryptoObject(BaseModel):
+class CryptoObject(LunchableModel):
     """
     Crypto Asset Object
 
     https://lunchmoney.dev/#crypto-object
     """
 
-    _id_description = "Unique identifier for a manual crypto account (no ID for synced accounts)"
+    _id_description = (
+        "Unique identifier for a manual crypto account (no ID for synced accounts)"
+    )
     _zabo_account_id_description = """
-    Unique identifier for a synced crypto account (no ID for manual accounts, 
+    Unique identifier for a synced crypto account (no ID for manual accounts,
     multiple currencies may have the same zabo_account_id)
     """
     _source_description = """
-    `synced` (this account is synced via a wallet, exchange, etc.) or `manual` (this account 
+    `synced` (this account is synced via a wallet, exchange, etc.) or `manual` (this account
     balance is managed manually)
     """
     _display_name_description = "Display name of the crypto asset (as set by user)"
     _balance_as_of_description = """
     Date/time the balance was last updated in ISO 8601 extended format
     """
-    _status_description = "The current status of the crypto account. Either active or in error."
-    _created_at_description = "Date/time the asset was created in ISO 8601 extended format"
+    _status_description = (
+        "The current status of the crypto account. Either active or in error."
+    )
+    _created_at_description = (
+        "Date/time the asset was created in ISO 8601 extended format"
+    )
 
     id: int = Field(description=_id_description)
     zabo_account_id: Optional[int] = Field(description=_zabo_account_id_description)
@@ -45,14 +52,16 @@ class CryptoObject(BaseModel):
     name: str = Field(description="Name of the crypto asset")
     display_name: Optional[str] = Field(description=_display_name_description)
     balance: float = Field(description="Current balance")
-    balance_as_of: Optional[datetime.datetime] = Field(description=_balance_as_of_description)
+    balance_as_of: Optional[datetime.datetime] = Field(
+        description=_balance_as_of_description
+    )
     currency: Optional[str] = Field(description="Abbreviation for the cryptocurrency")
     status: Optional[str] = Field(description=_status_description)
     institution_name: str = Field(description="Name of provider holding the asset")
     created_at: datetime.datetime = Field(description=_created_at_description)
 
 
-class CryptoParamsPut(BaseModel):
+class CryptoParamsPut(LunchableModel):
     """
     https://lunchmoney.dev/#update-manual-crypto-asset
     """
@@ -64,7 +73,7 @@ class CryptoParamsPut(BaseModel):
     currency: Optional[str]
 
 
-class _LunchMoneyCrypto(LunchMoneyAPIClient):
+class CryptoClient(LunchMoneyAPIClient):
     """
     Lunch Money Tag Interactions
     """
@@ -83,18 +92,22 @@ class _LunchMoneyCrypto(LunchMoneyAPIClient):
         -------
         List[CryptoObject]
         """
-        response_data = self._make_request(method=self.Methods.GET,
-                                           url_path=APIConfig.LUNCHMONEY_CRYPTO)
+        response_data = self._make_request(
+            method=self.Methods.GET, url_path=APIConfig.LUNCHMONEY_CRYPTO
+        )
         crypto_data = response_data["crypto"]
         crypto_objects = [CryptoObject(**item) for item in crypto_data]
         return crypto_objects
 
-    def update_crypto(self, crypto_id: int,
-                      name: Optional[str] = None,
-                      display_name: Optional[str] = None,
-                      institution_name: Optional[str] = None,
-                      balance: Optional[float] = None,
-                      currency: Optional[str] = None) -> CryptoObject:
+    def update_crypto(
+        self,
+        crypto_id: int,
+        name: Optional[str] = None,
+        display_name: Optional[str] = None,
+        institution_name: Optional[str] = None,
+        balance: Optional[float] = None,
+        currency: Optional[str] = None,
+    ) -> CryptoObject:
         """
         Update a Manual Crypto Asset
 
@@ -124,13 +137,21 @@ class _LunchMoneyCrypto(LunchMoneyAPIClient):
         -------
         CryptoObject
         """
-        crypto_body = CryptoParamsPut(name=name, display_name=display_name,
-                                      institution_name=institution_name, balance=balance,
-                                      currency=currency).dict(exclude_none=True)
-        response_data = self._make_request(method=self.Methods.PUT,
-                                           url_path=[APIConfig.LUNCHMONEY_CRYPTO,
-                                                     APIConfig.LUNCHMONEY_CRYPTO_MANUAL,
-                                                     crypto_id],
-                                           payload=crypto_body)
+        crypto_body = CryptoParamsPut(
+            name=name,
+            display_name=display_name,
+            institution_name=institution_name,
+            balance=balance,
+            currency=currency,
+        ).dict(exclude_none=True)
+        response_data = self._make_request(
+            method=self.Methods.PUT,
+            url_path=[
+                APIConfig.LUNCHMONEY_CRYPTO,
+                APIConfig.LUNCHMONEY_CRYPTO_MANUAL,
+                crypto_id,
+            ],
+            payload=crypto_body,
+        )
         crypto = CryptoObject(**response_data)
         return crypto
